# Pueblo - a Python toolbox library

[![Tests](https://github.com/pyveci/pueblo/actions/workflows/main.yml/badge.svg)](https://github.com/pyveci/pueblo/actions/workflows/main.yml)
[![Test coverage](https://img.shields.io/codecov/c/gh/pyveci/pueblo.svg)](https://codecov.io/gh/pyveci/pueblo/)
[![Python versions](https://img.shields.io/pypi/pyversions/pueblo.svg)](https://pypi.org/project/pueblo/)

[![License](https://img.shields.io/github/license/pyveci/pueblo.svg)](https://github.com/pyveci/pueblo/blob/main/LICENSE)
[![Status](https://img.shields.io/pypi/status/pueblo.svg)](https://pypi.org/project/pueblo/)
[![PyPI](https://img.shields.io/pypi/v/pueblo.svg)](https://pypi.org/project/pueblo/)
[![Downloads](https://pepy.tech/badge/pueblo/month)](https://pypi.org/project/pueblo/)


<!-- » [Documentation] -->

» [Changelog]
| [PyPI]
| [Issues]
| [Source code]
| [License]

[Changelog]: https://github.com/pyveci/pueblo/blob/main/CHANGES.md
[Documentation]: https://pueblo.readthedocs.io/
[Issues]: https://github.com/pyveci/pueblo/issues
[License]: https://github.com/pyveci/pueblo/blob/main/LICENSE
[PyPI]: https://pypi.org/project/pueblo/
[Source code]: https://github.com/pyveci/pueblo


## About

- A Python toolbox library.
- Contains Python code duplicated too often elsewhere.
- Finally, it is in one place.
- Here be dragons and gems.


## Setup

```shell
pip install --upgrade pueblo
```

After installation, you can verify if it was successful.
```shell
pueblo --version
```


## Usage

Read the source.


## Prior Art

- https://pypi.org/project/boltons/
